;; Generated package description from wisi.el  -*- no-byte-compile: t -*-
(define-package "wisi" "4.3.0.0.20231018.92008" "Utilities for implementing an indentation/navigation engine using a generalized LR parser" '((emacs "25.3") (seq "2.20")) :commit "183c4d0be060513fb7207c67ccc03b719c206427" :authors '(("Stephen Leake" . "stephen_leake@stephe-leake.org")) :maintainer '("Stephen Leake" . "stephen_leake@stephe-leake.org") :keywords '("parser" "indentation" "navigation") :url "https://stephe-leake.org/ada/wisitoken.html")
